# NotifD

### About

Simple DBus notification watcher scripts. 

### Usage

Running the watcher script:
```bash
$ notifd
```

Using the notifdctl:
```bash
$ notifdctl --help

Usage: .notifdctl-wrapped [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  clear
  list
  pop
```
